
rm(list=ls())


require(plyr)


library(ggplot2)


# read in functions
source('TrendAggregationFunctions_Simple.r')

# read in example dataset being outputs for individual trend analyses
AllTrends10FA  <- read.csv(file ="AllTrends10FA.csv")

# confidence categories
ConfCats<- ddply(AllTrends10FA, "npID", function(x) AggregateConfidence(x)); ConfCats

rowSums(ConfCats[,3:11])

# stack to make a plot
ConfCatsStack <- stack(ConfCats[, 3:11])
ConfCatsStack$ind <- factor(as.character(ConfCatsStack$ind), levels=names(ConfCats)[3:11])
ConfCatsStack$npID <- ConfCats$npID

library(gplots) # make colour ramp
myCols <- (colorRampPalette(c("red", "yellow", "green"))(n = 9))  #  red yellow green colour scale 

graphics.off(); x11(height = 7, width = 10); ggplot(data=ConfCatsStack, aes(x=npID, y=values, fill=ind)) + geom_bar(stat="identity") + scale_fill_manual(values=myCols)+ylab("Proportion of sites (%)")+ylim(0,100) + theme_bw()

# calculate PIT. (note the functions assumes decreasing is improving)
OUT <- ddply(AllTrends10FA, "npID", function(x) MonteCarloPIT(x)) # this evaluates the PIT using a Monte Carolo simulation
OUT2 <- ddply(AllTrends10FA, "npID", function(x) AnalysePIT(x)) # this evaluates the PIT statistic analytically



# convert variables for which decreasing is degrading by taking the complement. 
Reverse =  c("Clar", "CLAR", "Clarity", "MCI", "%EPT", "%EPT_Taxa", "QMCI") # variables for which decreasing = degrading  
OUT[OUT$npID %in% Reverse, "PIT"] <- 100 - OUT[OUT$npID %in% Reverse, "PIT"]; OUT
OUT2[OUT2$npID %in% Reverse, "PIT"] <- 100 - OUT2[OUT2$npID %in% Reverse, "PIT"]; OUT2

# compare analytic and Monte Carlo results
AllEsts <- data.frame(npID = OUT$npID, MCPIT = OUT$PIT, MCsdPIT = OUT$sdPIT, AnalyticPIT = OUT2[, "PIT"], Analytic_sdPIT = OUT2[, "sdPIT"] )

graphics.off(); x11(); ggplot(data=AllEsts,aes(x=MCPIT,y=AnalyticPIT,color=npID))+
  geom_point()+geom_abline(intercept=, slope=1, linetype=2, color="black", size=1)+
  geom_errorbarh(aes(xmax=MCPIT+MCsdPIT*1.96,xmin=MCPIT-MCsdPIT*1.96,width=0))+
  geom_errorbar(aes(ymax=AnalyticPIT+Analytic_sdPIT*1.96,ymin=AnalyticPIT-Analytic_sdPIT*1.96)) + 
  scale_color_manual(values = c("red", "blue", "green", "darkgreen", "black", "violet", "orange", "grey40"))

