



# this function assesses the PIT statistic analytically
AnalysePIT <- function(x,               # dataframe of trend assessement results that  contains column named "Probability", which is the probability the true trend was decreasing
                        myRound = 1) { # variables for which decreasing = degrading  
  
    x <- x[!is.na(x$Probability), ] # remove NA values that result from NotAnalysed
    N <- nrow(x)
    PIT <- round((sum(x$Probability >0.5) + sum(x$Probability == 0.5)/2)/N *100, myRound)
    VarP <- 1/N^2 * sum(x$Probability * (1-x$Probability))
    sdPIT <- round(sqrt(VarP)*100, myRound)
    return(data.frame(n.Sites=N, PIT = PIT, sdPIT= sdPIT)) 
}


# this function assesses the PIT statistic using a Monte Carlo simulation
MonteCarloPIT <- function(x,   # dataframe of trend assessement results that contains column named "Probability"
                          myRound = 1,  # for rounding the results
                          Realise = 1000) { #  number of realisations to run
  
    x<-x[!is.na(x$Probability),]   #Remove NA values
    N <- nrow(x)
  # the MC simulation 
    SIM <- lapply(x[, "Probability"],function(y) rbinom(Realise,1,as.numeric(y))) # Bernoulli (success/fail) outcome at site 
    SIM <- ldply(SIM, function(x) return(x))
    mySimulationResults<-data.frame(PIT = round(100*mean(colSums(SIM)/N), myRound), sdPIT = round(100*sd(colSums(SIM)/N),myRound)) # count successes and divide by total sites
    mySimulationResults$n.Sites <- nrow(x)
    mySimulationResults <- mySimulationResults[, c( "n.Sites", "PIT", "sdPIT")]
  return(mySimulationResults)
}


FaceValueCounter <- function(x,  myRound = 1) {  # for rounding the results) { # x = dataframe of trend assessement results that  contains column named "AnnualSenSlope" 

  x <- x[!is.na(x$AnnualSenSlope), ] # remove NA values that result from NotAnalysed 
  n <- nrow(x)
  if(n>0) { 
    n.Decreasing <- sum(x$AnnualSenSlope < 0) + round(sum(x$AnnualSenSlope == 0)/2)  # assign zero trends 50:50, myRound)
    n.Increasing <- sum(x$AnnualSenSlope > 0) + round(sum(x$AnnualSenSlope == 0)/2)  # assign zero trends 50:50, myRound)
    
    PropDecreasing <- round(n.Decreasing/n * 100, myRound)
    PropIncreasing <- round(n.Increasing/n * 100, myRound)
  } else {
    n.Decreasing <- NA
    n.Increasing <-NA
    PropDecreasing <- NA
    PropIncreasing <- NA
  }
  
  return(data.frame(n=n, n.Decreasing = n.Decreasing, n.Increasing = n.Increasing, PropDecreasing=PropDecreasing, PropIncreasing=PropIncreasing)) # 
}


# # function to assess % improving trends on the various variables at different levels of confidence
AggregateConfidence <- function(x) { # x = dataframe of trend assessement results that  contains column named "AnnualSenSlope" & a column named "Probability"
  # browser()
  x <- x[!is.na(x$Probability), ] # remove NA values that result from NotAnalysed 
  n <- nrow(x)
  ConfCats <- cut(x$Probability, breaks=  c(0, 0.01,0.05, 0.1,0.33,0.66,0.90, 0.95,0.99,1), labels = c("Exceptionally_unlikely",
                                                                                           "Extremely_unlikely",
                                                                                           "Very_unlikely",
                                                                                           "Unlikely",
                                                                                           "Likely_as_not",
                                                                                           "Likely",
                                                                                           "Very_likely",
                                                                                           "Extremely_likely",
                                                                                           "Virtually_certain"))
  Out <- c(No_sites = n,  100*table(ConfCats)/sum(table(ConfCats)))
  return(Out)
}
